% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/fxTWAPLS.R
\name{WAPLS.predict.w}
\alias{WAPLS.predict.w}
\title{WA-PLS predict function}
\usage{
WAPLS.predict.w(WAPLSoutput, fossil_taxa)
}
\arguments{
\item{WAPLSoutput}{The output of the \code{\link{WAPLS.w}} training function,
either with or without \code{fx} correction.}

\item{fossil_taxa}{Fossil taxa abundance data to reconstruct past climates,
each row represents a site to be reconstructed, each column represents a
taxon.}
}
\value{
A list of the reconstruction results. Each element in the list is
described below:
\describe{
\item{\code{fit}}{The fitted values using each number of components.}
\item{\code{nPLS}}{The total number of components extracted.}
}
}
\description{
WA-PLS predict function
}
\examples{
\dontrun{
# Load modern pollen data
modern_pollen <- read.csv("/path/to/modern_pollen.csv")
                                      
# Extract taxa
taxaColMin <- which(colnames(modern_pollen) == "taxa0")
taxaColMax <- which(colnames(modern_pollen) == "taxaN")
taxa <- modern_pollen[, taxaColMin:taxaColMax]

# Load reconstruction data
Holocene <- read.csv("/path/to/Holocene.csv")
taxaColMin <- which(colnames(Holocene) == "taxa0")
taxaColMax <- which(colnames(Holocene) == "taxaN")
core <- Holocene[, taxaColMin:taxaColMax]

# Get the frequency of each climate variable fx
fx_Tmin <- fxTWAPLS::fx(modern_pollen$Tmin, bin = 0.02)
fx_gdd <- fxTWAPLS::fx(modern_pollen$gdd, bin = 20)
fx_alpha <- fxTWAPLS::fx(modern_pollen$alpha, bin = 0.002)

# MTCO
## Train
fit_Tmin <- fxTWAPLS::WAPLS.w(modern_taxa = taxa, 
                              modern_climate = modern_pollen$Tmin, 
                              nPLS = 5)
fit_f_Tmin <- fxTWAPLS::WAPLS.w(modern_taxa = taxa, 
                                modern_climate = modern_pollen$Tmin,
                                nPLS = 5, 
                                usefx = TRUE, 
                                fx = fx_Tmin)
## Predict
fossil_Tmin <- fxTWAPLS::WAPLS.predict.w(fit_Tmin, core)
fossil_f_Tmin <- fxTWAPLS::WAPLS.predict.w(fit_f_Tmin, core)
}

}
\seealso{
\code{\link{WAPLS.w}}
}
